# etlx
![PyPI](https://img.shields.io/pypi/v/etlx) 
![PyPI - License](https://img.shields.io/pypi/l/etlx)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/etlx)

![GitHub Relese Version](https://img.shields.io/github/v/release/kedikx/etlx)
![GitHub Release Date](https://img.shields.io/github/release-date/kedikx/etlx)

![develop](https://github.com/kedikx/etlx/workflows/etlx-build/badge.svg?branch=develop)
[![codecov](https://codecov.io/gh/kedikx/etlx/branch/develop/graph/badge.svg?token=UXCMNC0IU3)](https://codecov.io/gh/kedikx/etlx)

